@@ -2,7 +2,7 @@ import json
 
 """
 caution! nan과 같은 특수 객체는 registering이 불가능합니다.
-string을 registering 하시려면 "'string_name'" 형태로 하셔야 합니다.
+string을 registering 하시려면 "'string_name'" 형태로 하셔야 합니다. * json 제
 """
 
 class VariableHolder:
@@ -13,9 +13,11 @@ class VariableHolder:
 
     @staticmethod
     def from_json(path):
-        with open(path) as f:
-            kwargs = json.loads(f)
-        return VariableHolder(**kwargs)
+        with open(path, "r") as f:
+            kwargs = json.load(f)
+        vh = VariableHolder()
+        for key, value in kwargs.items():
+            vh.__setattr__(key, value)
 
     def add_variables(self, **kwargs):
         for name, value in kwargs.items():
@@ -27,7 +29,6 @@ class VariableHolder:
         self.add_variables(**{variable_name:variable})
 
     def set_value(self, variable_name: str, value: float):
-
         if variable_name in dir(self):
             exec(f"self.{variable_name} = {value}")
         else:
